How to install Tamarco
======================

Tamarco is compatible with Python >= 3.6. Recommended version is Python 3.7.

To install Tamarco, simply run this command in your terminal of choice::

    $ pip3 install tamarco
